@@ -76,6 +76,7 @@ import org.junit.Test;
 public class TestSSLContextBuilder {
 
     private static final String PROVIDER_SUN_JSSE = "SunJSSE";
+    private static final int TIMEOUT = 5000;
     private ExecutorService executorService;
 
     @After
@@ -86,6 +87,9 @@ public class TestSSLContextBuilder {
         }
     }
 
+    private URL getResource(final String name) {
+        return getClass().getResource(name);
+    }
 
     @Test
     public void testBuildDefault() throws Exception {
@@ -128,7 +132,7 @@ public class TestSSLContextBuilder {
 
     @Test(expected=KeyStoreException.class)
     public void testBuildNoSuchKeyStoreType() throws Exception {
-        final URL resource1 = getClass().getResource("/test-keypasswd.keystore");
+        final URL resource1 = getResource("/test-keypasswd.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "password";
         SSLContextBuilder.create()
@@ -139,7 +143,7 @@ public class TestSSLContextBuilder {
 
     @Test(expected=NoSuchAlgorithmException.class)
     public void testBuildNoSuchKeyManagerFactoryAlgorithm() throws Exception {
-        final URL resource1 = getClass().getResource("/test-keypasswd.keystore");
+        final URL resource1 = getResource("/test-keypasswd.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "password";
         SSLContextBuilder.create()
@@ -150,7 +154,7 @@ public class TestSSLContextBuilder {
 
     @Test(expected=NoSuchAlgorithmException.class)
     public void testBuildNoSuchTrustManagerFactoryAlgorithm() throws Exception {
-        final URL resource1 = getClass().getResource("/test-keypasswd.keystore");
+        final URL resource1 = getResource("/test-keypasswd.keystore");
         final String storePassword = "nopassword";
         SSLContextBuilder.create()
                 .setTrustManagerFactoryAlgorithm(" BAD ")
@@ -172,7 +176,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testKeyWithAlternatePassword() throws Exception {
-        final URL resource1 = getClass().getResource("/test-keypasswd.keystore");
+        final URL resource1 = getResource("/test-keypasswd.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "password";
         final SSLContext sslContext = SSLContextBuilder.create()
@@ -186,7 +190,7 @@ public class TestSSLContextBuilder {
 
     @Test(expected=UnrecoverableKeyException.class)
     public void testKeyWithAlternatePasswordInvalid() throws Exception {
-        final URL resource1 = getClass().getResource("/test-keypasswd.keystore");
+        final URL resource1 = getResource("/test-keypasswd.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "!password";
         SSLContextBuilder.create()
@@ -197,7 +201,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testSSLHanskshakeServerTrusted() throws Exception {
-        final URL resource1 = getClass().getResource("/test.keystore");
+        final URL resource1 = getResource("/test.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
@@ -230,7 +234,7 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final Socket clientSocket = clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
             final InputStream inputStream = clientSocket.getInputStream();
             Assert.assertEquals('H', inputStream.read());
             Assert.assertEquals('i', inputStream.read());
@@ -245,14 +249,14 @@ public class TestSSLContextBuilder {
 
     @Test(expected = IOException.class)
     public void testSSLHanskshakeServerNotTrusted() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
                 .loadKeyMaterial(resource1, storePassword.toCharArray(), keyPassword.toCharArray())
                 .build();
         Assert.assertNotNull(serverSslContext);
-        final URL resource2 = getClass().getResource("/test.keystore");
+        final URL resource2 = getResource("/test.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .build();
@@ -276,7 +280,8 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final SSLSocket clientSocket = (SSLSocket) clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             clientSocket.startHandshake();
         } finally {
             clientSocket.close();
@@ -285,7 +290,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testSSLHanskshakeServerCustomTrustStrategy() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
@@ -333,7 +338,8 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final SSLSocket clientSocket = (SSLSocket) clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             final InputStream inputStream = clientSocket.getInputStream();
             Assert.assertEquals('H', inputStream.read());
             Assert.assertEquals('i', inputStream.read());
@@ -351,8 +357,7 @@ public class TestSSLContextBuilder {
         final X509Certificate cert1 = certs[0];
         final Principal subjectDN1 = cert1.getSubjectDN();
         Assert.assertNotNull(subjectDN1);
-        Assert.assertEquals("CN=Test Server, OU=HttpComponents Project, O=Apache Software Foundation, " +
-                "L=Unknown, ST=Unknown, C=Unknown", subjectDN1.getName());
+        Assert.assertEquals("CN=Test Server, OU=HttpComponents Project, O=Apache Software Foundation", subjectDN1.getName());
         final X509Certificate cert2 = certs[1];
         final Principal subjectDN2 = cert2.getSubjectDN();
         Assert.assertNotNull(subjectDN2);
@@ -367,14 +372,14 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testSSLHanskshakeClientUnauthenticated() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
                 .loadKeyMaterial(resource1, storePassword.toCharArray(), keyPassword.toCharArray())
                 .build();
         Assert.assertNotNull(serverSslContext);
-        final URL resource2 = getClass().getResource("/test-client.keystore");
+        final URL resource2 = getResource("/test-client.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .build();
@@ -408,7 +413,8 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final SSLSocket clientSocket = (SSLSocket) clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             clientSocket.startHandshake();
             final InputStream inputStream = clientSocket.getInputStream();
             Assert.assertEquals('H', inputStream.read());
@@ -424,14 +430,14 @@ public class TestSSLContextBuilder {
 
     @Test(expected = IOException.class)
     public void testSSLHanskshakeClientUnauthenticatedError() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
                 .loadKeyMaterial(resource1, storePassword.toCharArray(), keyPassword.toCharArray())
                 .build();
         Assert.assertNotNull(serverSslContext);
-        final URL resource2 = getClass().getResource("/test-client.keystore");
+        final URL resource2 = getResource("/test-client.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .build();
@@ -457,7 +463,8 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final SSLSocket clientSocket = (SSLSocket) clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             clientSocket.startHandshake();
         } finally {
             clientSocket.close();
@@ -466,7 +473,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testSSLHanskshakeClientAuthenticated() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
@@ -474,7 +481,7 @@ public class TestSSLContextBuilder {
                 .loadKeyMaterial(resource1, storePassword.toCharArray(), keyPassword.toCharArray())
                 .build();
         Assert.assertNotNull(serverSslContext);
-        final URL resource2 = getClass().getResource("/test-client.keystore");
+        final URL resource2 = getResource("/test-client.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .loadKeyMaterial(resource2, storePassword.toCharArray(), storePassword.toCharArray())
@@ -504,7 +511,8 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final SSLSocket clientSocket = (SSLSocket) clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             clientSocket.startHandshake();
             final InputStream inputStream = clientSocket.getInputStream();
             Assert.assertEquals('H', inputStream.read());
@@ -520,7 +528,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testSSLHanskshakeClientAuthenticatedPrivateKeyStrategy() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
@@ -540,7 +548,7 @@ public class TestSSLContextBuilder {
             }
         };
 
-        final URL resource2 = getClass().getResource("/test-client.keystore");
+        final URL resource2 = getResource("/test-client.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .loadKeyMaterial(resource2, storePassword.toCharArray(), storePassword.toCharArray(), privateKeyStrategy)
@@ -570,7 +578,8 @@ public class TestSSLContextBuilder {
         final int localPort = serverSocket.getLocalPort();
         final SSLSocket clientSocket = (SSLSocket) clientSslContext.getSocketFactory().createSocket();
         try {
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             clientSocket.startHandshake();
             final InputStream inputStream = clientSocket.getInputStream();
             Assert.assertEquals('H', inputStream.read());
@@ -582,21 +591,20 @@ public class TestSSLContextBuilder {
 
         final Principal clientPrincipal = future.get(5, TimeUnit.SECONDS);
         Assert.assertNotNull(clientPrincipal);
-        Assert.assertEquals("CN=Test Client 2,OU=HttpComponents Project,O=Apache Software Foundation," +
-                "L=Unknown,ST=Unknown,C=Unknown", clientPrincipal.getName());
+        Assert.assertEquals("CN=Test Client 2,OU=HttpComponents Project,O=Apache Software Foundation", clientPrincipal.getName());
     }
 
 
     @Test(expected = IOException.class)
     public void testSSLHanskshakeProtocolMismatch1() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
                 .loadKeyMaterial(resource1, storePassword.toCharArray(), keyPassword.toCharArray())
                 .build();
         Assert.assertNotNull(serverSslContext);
-        final URL resource2 = getClass().getResource("/test-client.keystore");
+        final URL resource2 = getResource("/test-client.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .build();
@@ -627,7 +635,8 @@ public class TestSSLContextBuilder {
             final Set<String> supportedClientProtocols = new LinkedHashSet<String>(Arrays.asList(clientSocket.getSupportedProtocols()));
             Assert.assertTrue(supportedClientProtocols.contains("SSLv3"));
             clientSocket.setEnabledProtocols(new String[] {"SSLv3"} );
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             clientSocket.startHandshake();
         } finally {
             clientSocket.close();
@@ -636,14 +645,14 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testSSLHanskshakeProtocolMismatch2() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext serverSslContext = SSLContextBuilder.create()
                 .loadKeyMaterial(resource1, storePassword.toCharArray(), keyPassword.toCharArray())
                 .build();
         Assert.assertNotNull(serverSslContext);
-        final URL resource2 = getClass().getResource("/test-client.keystore");
+        final URL resource2 = getResource("/test-client.keystore");
         final SSLContext clientSslContext = SSLContextBuilder.create()
                 .loadTrustMaterial(resource2, storePassword.toCharArray())
                 .build();
@@ -675,7 +684,8 @@ public class TestSSLContextBuilder {
                     Arrays.asList(clientSocket.getSupportedProtocols()));
             Assert.assertTrue(supportedClientProtocols.contains("TLSv1"));
             clientSocket.setEnabledProtocols(new String[] { "TLSv1" });
-            clientSocket.connect(new InetSocketAddress("localhost", localPort), 5000);
+            clientSocket.connect(new InetSocketAddress("localhost", localPort), TIMEOUT);
+            clientSocket.setSoTimeout(TIMEOUT);
             final Class<? extends IOException> expectedExceptionClass = SystemUtils.IS_OS_WINDOWS
                     && SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_1_7) ? SocketException.class
                             : SSLHandshakeException.class;
@@ -692,7 +702,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testBuildWithProvider() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext sslContext=SSLContextBuilder.create()
@@ -704,7 +714,7 @@ public class TestSSLContextBuilder {
 
     @Test
     public void testBuildWithProviderName() throws Exception {
-        final URL resource1 = getClass().getResource("/test-server.keystore");
+        final URL resource1 = getResource("/test-server.keystore");
         final String storePassword = "nopassword";
         final String keyPassword = "nopassword";
         final SSLContext sslContext=SSLContextBuilder.create()
